
%****************************
% Population
%****************************
employed = 2582000;                 %persons
unemployed = 98000;                 %persons
work_force = employed + unemployed; %persons
other_beneficiaries = 1400000;      %persons

%Distribution of private and public employees after pay rate
D_priv = [0.01, 0.04, 0.16, 0.22, 0.25, 0.15, 0.1, 0.07]';
D_pub = [0.005, 0.04, 0.1, 0.20, 0.205, 0.22, 0.12, 0.11]';

%Employees distributed after sector and pay rate
E_priv = 0.7*employed*D_priv;   % private sector
E_pub = 0.3*employed*D_pub;     % public sector

%****************************
% Salaries
%****************************
%all wage levels [NOK/month/person]
wage_levels = [70000,60000,50000,45000,40000,35000,30000,25000]'; 
mean_priv = wage_levels'*D_priv; %average private salary [NOK/month/person]
mean_pub = wage_levels'*D_pub;   %average public salary  [NOK/month/person]
other_benefits = other_beneficiaries*20000;%NOK/month for all beneficiaries

%****************************
% Gross Incomes (GI)
%****************************
%Employed
GI_priv = E_priv.*wage_levels;  %GI per month for all private employees
GI_pub = E_pub.*wage_levels;    %GI per month for all public employees
GI_e = GI_priv + GI_pub;        %GI for all employees

%Not working
GI_ue = 0.642*unemployed*D_priv'*wage_levels;  %GI per month all unemployed
GI_nw = other_benefits + GI_ue;           %GI per month for all not working

%****************************
% Taxes
%****************************
VAT = 0.20;     %Value Added Taxes
tr = [0.33, 0.3, 0.3, 0.28, 0.28, 0.28, 0.25, 0.25]'; %tax rate employed
tr_nw = 0.20;   %tax rate not working

%****************************
% Net income
%****************************
NI_e = GI_e'*(1-tr);        %net income for all employed
NI_nw = GI_nw*(1-tr_nw);    %net income for all not working

%****************************
% Household consumption
%****************************
C_h = NI_e + NI_nw;         %Households' consumption at t0

%****************************
% Public expenditures
%****************************
C_pub = 15*10^9;    %Public consumption [NOK/month]
I_pub = 10*10^9;    %Public investments [NOK/month]

%****************************
% Foreign sector
%****************************
export_petroleum = 542/12*10^9; %Export of petroleum at t0 [NOK/month]
export_other = export_petroleum*0.25/0.75; %Other export [NOK/month]
import = 528/12*10^9;   %Import [NOK/month]
import_gain = import/C_h;
NX = export_petroleum + export_other - import;  %Net export [NOK/month]
exchange_gain = (export_other+export_petroleum)/import;
exchange_gain_US = 5.8753;  %price of 1 USD in NOK at t0

oil_prices_data %Retreive oil prices 
export_gain_petroleum = mean(export_petroleum./oil_prices(1:12));

%****************************
%Firms
%****************************
%share of firms' income used in firms sector:
firms_purchase_gain = 0.4;

%firms income at t0:
firms_income =((sum(C_h)+C_pub)*(1-VAT)+I_pub+NX)/(1-firms_purchase_gain);

%share of firms' income used as salaries
salary_gain = sum(GI_priv)/firms_income;

%share of firms' income used to pay taxes and fees to the government:
govn_share_firms = 1 - firms_purchase_gain - salary_gain;

%share of firms' spending in firms sector used for investments:
I_f = 0.4; 

%****************************
% Economic mood
%****************************
%Regular model
h_min = (work_force-sum(E_pub)-0.25*work_force)/(sum(E_priv)+unemployed);
h = 1 - 0.5*(1-h_min);
g = 10;
u = sum(E_priv)/(sum(E_priv)+unemployed);
mood = 1/(1+exp(-g*(u-h))); %initial mood

%JG model
h_min_jg=(work_force-sum(E_pub)-0.35*work_force)/(sum(E_priv)+unemployed);
h_jg = 1 - 0.5*(1-h_min_jg);

%BI model
h_bi = h_jg;

%****************************
% Time constants
%****************************
%***** Households ******
%Private and Public employees
Th_p_max = 1.4; 
Th_p_min = 1.8;
Th_p = Th_p_min + mood*(Th_p_max-Th_p_min);

%Not working
Th_ni_max = 1;
Th_ni_min = 1.2;
Th_ni = Th_ni_min + mood*(Th_ni_max-Th_ni_min);

%***** Foreign Sector *****
Te_o = 2;   %other export
Te_p = 2;   %petrolium export
Ti = 2;     %import
T_c = 0.5;  %exchange rate

%***** Firms *****
Tf_max = 1;
Tf_min = 1.5;
Tf = Tf_min + mood*(Tf_max-Tf_min);
Te = 6; %firms employment

%***** Economic Mood *****
Tm = 4;

%***** unemployment benefits *****
Tg_ub = 1;
Tg_rb = 24;

%****************************
% Simulation times
%****************************
t_crisis = 24;  %Time when new regime introduced
t_end = 72;     %End of simulation